/**
 * @module package/quiqqer/socketserver/bin/frontend/Client
 * @author www.pcsg.de (Henning Leutz)
 */
define('package/quiqqer/socketserver/bin/frontend/Client', [
    'qui/QUI',
    'Ajax',
], function (QUI, QUIAjax) {
    "use strict";

    const clients = {};

    return {

        /**
         * Return a websocket client
         *
         * @param endPoint
         * @return {Promise}
         */
        getClient: function (endPoint) {
            if (typeof clients[endPoint] !== 'undefined') {
                return Promise.resolve(clients[endPoint]);
            }

            return new Promise(function (resolve, reject) {
                if (!("WebSocket" in window)) {
                    reject("Websocket is not supported by your browser");
                    return;
                }

                QUIAjax.get('package_quiqqer_socketserver_ajax_frontend_getClientSettings', function (conf) {
                    let protocol = window.location.protocol.indexOf('https') !== -1 ? 'wss://' : 'ws://';
                    let url = protocol + conf.host;

                    if (conf.port !== '') {
                        url = url + ':' + conf.port.toString();
                    }

                    url = url + endPoint;

                    const Client = new WebSocket(url);

                    clients[endPoint] = Client;
                    resolve(Client);
                }, {
                    'package': 'quiqqer/socketserver'
                });
            });
        }
    }
});
