<?php

define('QUIQQER_SYSTEM', true);
putenv('RATCHET_DISABLE_XDEBUG_WARN=1');

use \QUI\SocketServer\App;

require dirname(dirname(dirname(__FILE__))).'/header.php';

$Config = QUI::getPackage('quiqqer/socketserver')->getConfig();
$host   = $Config->getValue('server', 'host');
$port   = $Config->getValue('server', 'port');

$app = new App($host, $port);

// call provider
$packages = QUI::getPackageManager()->getInstalled();

foreach ($packages as $package) {
    try {
        $Package = QUI::getPackage($package['name']);
    } catch (QUI\Exception $Exception) {
        QUI\System\Log::writeException($Exception);
        continue;
    }

    $servers = $Package->getProvider('socketserver');

    foreach ($servers as $server) {
        $Server = new $server();

        if ($Server instanceof QUI\SocketServer\ProviderInterface) {
            $Server->registerRoute($app);
        }
    }
}

$app->route('/echo', new Ratchet\Server\EchoServer, ['*']);

$server = $app->getServer();

// tick implementation
// @todo check for better solutions
// @todo use this only if a tick component exist
$server->loop->addPeriodicTimer(1, function () use ($server, $app) {
    foreach ($app->routes as $route) {
        $controller = $route->getDefault('_controller');

        if (!method_exists($controller, 'getComponent')) {
            continue;
        }

        $component = $controller->getComponent();

        if (method_exists($component, 'onTick')) {
            $component->onTick();
        }
    }
});

echo 'Listen on'.PHP_EOL;
echo 'Host: '.$host.PHP_EOL;
echo 'Port: '.$port.PHP_EOL;
echo PHP_EOL;
echo 'Routes: '.PHP_EOL;

foreach ($app->routes as $route) {
    echo '- '.$route->getPath().PHP_EOL;
}

$app->run();
